@@ -124,6 +124,7 @@ class Task(_BaseEvergreenObject):
     mainline = evg_attrib("mainline")
     order = evg_attrib("order")
     project_id = evg_attrib("project_id")
+    project_identifier = evg_attrib("project_identifier")
     priority = evg_attrib("priority")
     restarts = evg_attrib("restarts")
     revision = evg_attrib("revision")
@@ -165,13 +166,11 @@ class Task(_BaseEvergreenObject):
 
     def get_project_identifier(self) -> str:
         """
-        Retrieve the human-readable project id from Evergreen.
-
-        This requires the caller to be Admin on the project.
+        Return the human-readable project id. Can also be accessed as an attribute.
 
         :return: Human-readable project id.
         """
-        return self._api.project_by_id(self.project_id).identifier
+        return self.project_identifier
 
     def retrieve_log(self, log_name: str, raw: bool = False) -> str:
         """
